@@ -35,12 +35,11 @@ import target_areas_window as taw
 
 from delegates import ExercisesDelegate
 
-from PyQt4.QtCore import QModelIndex
 class ExercisesWindow(QMainWindow, Ui_ExercisesWindow):
 
     def __init__(self, parent=None, database=None, t_name=None):
         super(ExercisesWindow, self).__init__(parent)
-        self.setAttribute(Qt.WA_Maemo5StackedWindow)
+        self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
 
         self.setupUi(self)
         self.config = c.Config()
